﻿using System.Globalization;
using System.Text.RegularExpressions;

namespace TestProject
{
    /// <summary>
    /// 폰트 컬렉션
    /// </summary>
    public class FontCollection : List<FontModel>
    {
        //////////////////////////////////////////////////////////////////////////////////////////////////// Constructor
        ////////////////////////////////////////////////////////////////////////////////////////// Public

        #region 생성자 - FontCollection()

        /// <summary>
        /// 생성자
        /// </summary>
        public FontCollection()
        {
            for(int i = 0xf0ff ; i < 0xf3aa; i++)
            {
                string escapedUnicode    = "\\u" + i.ToString("x4");
                string nonEscapedUnicode = GetNonEscapedUnicodeString(escapedUnicode);

                FontImageSource fontImageSource = new FontImageSource();

                fontImageSource.Color      = Colors.Blue;
                fontImageSource.FontFamily = "ionicons";
                fontImageSource.Glyph      = nonEscapedUnicode;

                Add(new FontModel { Icon = fontImageSource, Glyph = escapedUnicode });
            }
        }

        #endregion

        //////////////////////////////////////////////////////////////////////////////////////////////////// Method
        ////////////////////////////////////////////////////////////////////////////////////////// Private

        #region 비 이스케이프 유니코드 문자열 구하기 - GetNonEscapedUnicodeString(sourceEscapedUnicodeString)

        /// <summary>
        /// 비 이스케이프 유니코드 문자열 구하기
        /// </summary>
        /// <param name="sourceEscapedUnicodeString">소스 이스케이프 유니코드 문자열</param>
        /// <returns>비 이스케이프 유니코드 문자열</returns>
        private string GetNonEscapedUnicodeString(string sourceEscapedUnicodeString)
        {
            return Regex.Replace
            (
                sourceEscapedUnicodeString,
                @"\\u(?<Value>[a-zA-Z0-9]{4})",
                m =>
                {
                    return ((char)int.Parse(m.Groups["Value"].Value, NumberStyles.HexNumber)).ToString();
                }
            );
        }

        #endregion
    }
}